Stan Math Library: stan/math/rev/mat/fun/sort_asc.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
sort_asc.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <algorithm>`
`#include <functional>`
`#include <valarray>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
std::vector< var > | stan::math::sort_asc (std::vector< var > xs)
| Return the specified standard vector in ascending order with gradients kept. More...
template<int R, int C>
Eigen::Matrix< var, R, C > | stan::math::sort_asc (Eigen::Matrix< var, R, C > xs)
| Return the specified eigen vector in ascending order with gradients kept. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.